module PlanetExpressExpress
  require 'date'
  class ShipmentReader
    def initialize(prices)
      @prices = prices
    end

    # Expects to read a file
    def read_shipments(io)
      shipments = {
        S: [],
        M: [],
        L: []
      }

      current_month = 0
      current_year = 0
      x = 0
      io.lines.each do |line|
        shipment = parse(line)

        if shipment[:date].year != current_year || shipment[:date].month != current_month
          close_month(shipments)
        end
        shipments[shipment[:size]].last.push(shipment)

        current_year = shipment[:date].year
        current_month = shipment[:date].month
        x += 1
      end

      shipments
    end

    private

    attr_reader :prices

    def close_month(shipments)
      shipments.keys.each do |key|
        shipments[key].push([])
      end
    end

    def parse(line)
      parts = line.split(" ")

      shipment = {
        date: Date.parse(parts[0]),
        size: parts[1]&.to_sym,
        provider: parts[2]&.to_sym,
        price: 0,
        discount: 0,
        valid: true
      }

      shipment[:price] = prices[
        [
          shipment[:provider], shipment[:size]
        ]
      ]

      shipment
    end
  end
end
